@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2007 Kenneth J. Pronovici.
+# Copyright (c) 2004-2008 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: filesystem.py 1210 2007-07-05 03:04:54Z pronovic $
+# Revision : $Id: filesystem.py 914 2008-04-28 02:40:04Z pronovic $
 # Purpose  : Provides filesystem-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -52,13 +52,14 @@ import sys
 import os
 import re
 import sha
+import math
 import logging
 import tarfile
 
 # Cedar Backup modules
 from CedarBackup2.knapsack import firstFit, bestFit, worstFit, alternateFit
 from CedarBackup2.util import AbsolutePathList, ObjectTypeList, UnorderedList, RegexList
-from CedarBackup2.util import removeKeys, displayBytes, calculateFileAge, encodePath
+from CedarBackup2.util import removeKeys, displayBytes, calculateFileAge, encodePath, dereferenceLink
 
 
 ########################################################################
@@ -357,7 +358,7 @@ class FilesystemList(list):
       logger.debug("Added directory to list: [%s]" % path)
       return 1
 
-   def addDirContents(self, path, recursive=True, addSelf=True):
+   def addDirContents(self, path, recursive=True, addSelf=True, linkDepth=0, dereference=False):
       """
       Adds the contents of a directory to the list.
 
@@ -372,14 +373,23 @@ class FilesystemList(list):
       directory and all of its contents will be recursively excluded from the
       list.
 
-      @note: If the passed-in directory happens to be a soft link, it will
-      still be recursed.  However, any soft links I{within} the directory will
-      only be added by name, not recursively.   Any invalid soft links (i.e.
-      soft links that point to non-existent items) will be silently ignored.
+      @note: If the passed-in directory happens to be a soft link, it will be
+      recursed.  However, the linkDepth parameter controls whether any soft
+      links I{within} the directory will be recursed.  The link depth is
+      maximum depth of the tree at which soft links should be followed.  So, a
+      depth of 0 does not follow any soft links, a depth of 1 follows only
+      links within the passed-in directory, a depth of 2 follows the links at
+      the next level down, etc.
+
+      @note: Any invalid soft links (i.e.  soft links that point to
+      non-existent items) will be silently ignored.
 
       @note: The L{excludeDirs} flag only controls whether any given directory
       path itself is added to the list once it has been discovered.  It does
       I{not} modify any behavior related to directory recursion.
+
+      @note: If you call this method I{on a link to a directory} that link will
+      never be dereferenced (it may, however, be followed).
    
       @param path: Directory path whose contents should be added to the list
       @type path: String representing a path on disk
@@ -390,6 +400,12 @@ class FilesystemList(list):
       @param addSelf: Indicates whether the directory itself should be added to the list.
       @type addSelf: Boolean value
 
+      @param linkDepth: Maximum depth of the tree at which soft links should be followed
+      @type linkDepth: Integer value, where zero means not to follow any soft links
+
+      @param dereference: Indicates whether soft links, if followed, should be dereferenced
+      @type dereference: Boolean value
+
       @return: Number of items recursively added to the list
 
       @raise ValueError: If path is not a directory or does not exist.
@@ -397,9 +413,9 @@ class FilesystemList(list):
       """
       path = encodePath(path)
       path = normalizeDir(path)
-      return self._addDirContentsInternal(path, recursive=recursive, includePath=addSelf)
+      return self._addDirContentsInternal(path, addSelf, recursive, linkDepth, dereference)
 
-   def _addDirContentsInternal(self, path, includePath=True, recursive=True):
+   def _addDirContentsInternal(self, path, includePath=True, recursive=True, linkDepth=0, dereference=False):
       """
       Internal implementation of C{addDirContents}.
 
@@ -411,9 +427,26 @@ class FilesystemList(list):
       interface, C{addDirContents} ends up being wholly implemented in terms 
       of this method.
 
+      The linkDepth parameter controls whether soft links are followed when we
+      are adding the contents recursively.  Any recursive calls reduce the
+      value by one.  If the value zero or less, then soft links will just be
+      added as directories, but will not be followed.  This means that links
+      are followed to a I{constant depth} starting from the top-most directory.
+
+      There is one difference between soft links and directories: soft links
+      that are added recursively are not placed into the list explicitly.  This
+      is because if we do add the links recursively, the resulting tar file
+      gets a little confused (it has a link and a directory with the same
+      name).
+
+      @note: If you call this method I{on a link to a directory} that link will
+      never be dereferenced (it may, however, be followed).
+
       @param path: Directory path whose contents should be added to the list.
       @param includePath: Indicates whether to include the path as well as contents.
       @param recursive: Indicates whether directory contents should be added recursively.
+      @param linkDepth: Depth of soft links that should be followed
+      @param dereference: Indicates whether soft links, if followed, should be dereferenced
 
       @return: Number of items recursively added to the list
 
@@ -442,13 +475,31 @@ class FilesystemList(list):
       for entry in os.listdir(path):
          entrypath = os.path.join(path, entry)
          if os.path.isfile(entrypath):
+            if linkDepth > 0 and dereference:
+               derefpath = dereferenceLink(entrypath)
+               if derefpath != entrypath:
+                  added += self.addFile(derefpath)
             added += self.addFile(entrypath)
          elif os.path.isdir(entrypath):
             if os.path.islink(entrypath):
-               added += self.addDir(entrypath)
+               if recursive:
+                  if linkDepth > 0:
+                     newDepth = linkDepth - 1;
+                     if dereference:
+                        derefpath = dereferenceLink(entrypath)
+                        if derefpath != entrypath:
+                           added += self._addDirContentsInternal(derefpath, True, recursive, newDepth, dereference)
+                        added += self.addDir(entrypath)
+                     else:
+                        added += self._addDirContentsInternal(entrypath, False, recursive, newDepth, dereference)
+                  else:
+                     added += self.addDir(entrypath)
+               else:
+                  added += self.addDir(entrypath)
             else:
                if recursive:
-                  added += self._addDirContentsInternal(entrypath)
+                  newDepth = linkDepth - 1;
+                  added += self._addDirContentsInternal(entrypath, True, recursive, newDepth, dereference)
                else:
                   added += self.addDir(entrypath)
       return added
@@ -1193,7 +1244,7 @@ class PurgeItemList(FilesystemList):
    # Add methods
    ##############
 
-   def addDirContents(self, path, recursive=True, addSelf=False):
+   def addDirContents(self, path, recursive=True, addSelf=True, linkDepth=0, dereference=False):
       """
       Adds the contents of a directory to the list.
 
@@ -1208,10 +1259,16 @@ class PurgeItemList(FilesystemList):
       directory and all of its contents will be recursively excluded from the
       list.
 
-      @note: If the passed-in directory happens to be a soft link, it will
-      still be recursed.  However, any soft links I{within} the directory will
-      only be added by name, not recursively.   Any invalid soft links (i.e.
-      soft links that point to non-existent items) will be silently ignored.
+      @note: If the passed-in directory happens to be a soft link, it will be
+      recursed.  However, the linkDepth parameter controls whether any soft
+      links I{within} the directory will be recursed.  The link depth is
+      maximum depth of the tree at which soft links should be followed.  So, a
+      depth of 0 does not follow any soft links, a depth of 1 follows only
+      links within the passed-in directory, a depth of 2 follows the links at
+      the next level down, etc.
+
+      @note: Any invalid soft links (i.e.  soft links that point to
+      non-existent items) will be silently ignored.
 
       @note: The L{excludeDirs} flag only controls whether any given soft link
       path itself is added to the list once it has been discovered.  It does
@@ -1221,6 +1278,9 @@ class PurgeItemList(FilesystemList):
       path itself is added to the list once it has been discovered.  It does
       I{not} modify any behavior related to directory recursion.
 
+      @note: If you call this method I{on a link to a directory} that link will
+      never be dereferenced (it may, however, be followed).
+
       @param path: Directory path whose contents should be added to the list
       @type path: String representing a path on disk
 
@@ -1229,6 +1289,12 @@ class PurgeItemList(FilesystemList):
    
       @param addSelf: Ignored in this subclass.
 
+      @param linkDepth: Depth of soft links that should be followed
+      @type linkDepth: Integer value, where zero means not to follow any soft links
+
+      @param dereference: Indicates whether soft links, if followed, should be dereferenced
+      @type dereference: Boolean value
+
       @return: Number of items recursively added to the list
 
       @raise ValueError: If path is not a directory or does not exist.
@@ -1236,7 +1302,7 @@ class PurgeItemList(FilesystemList):
       """
       path = encodePath(path)
       path = normalizeDir(path)
-      return super(PurgeItemList, self)._addDirContentsInternal(path, includePath=False, recursive=recursive)
+      return super(PurgeItemList, self)._addDirContentsInternal(path, False, recursive, linkDepth, dereference)
 
 
    ##################
@@ -1276,8 +1342,9 @@ class PurgeItemList(FilesystemList):
       for entry in self[:]:
          if os.path.isfile(entry) and not os.path.islink(entry):
             try:
-               age = calculateFileAge(entry)
-               if age < daysOld:
+               ageInDays = calculateFileAge(entry)
+               ageInWholeDays = math.floor(ageInDays)
+               if ageInWholeDays < daysOld:
                   removed += 1
                   self.remove(entry)
             except OSError:
@@ -1372,6 +1439,8 @@ def compareContents(path1, path2, verbose=False):
    between the directories containing different files, and containing the same
    files with differing content.
 
+   @note: Symlinks are I{not} followed for the purposes of this comparison.
+
    @param path1: First path to compare.
    @type path1: String representing a path on disk
 
