@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 1233 2007-09-20 03:07:42Z pronovic $
+# Revision : $Id: release.py 917 2008-05-06 00:56:53Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -33,8 +33,8 @@ Provides location to maintain version information.
 
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
-COPYRIGHT   = "2004-2007"
-VERSION     = "2.14.0"
-DATE        = "19 Sep 2007"
-URL         = "http://cedar-solutions.com/software/cedar-backup"
+COPYRIGHT   = "2004-2008"
+VERSION     = "2.18.0"
+DATE        = "05 May 2008"
+URL         = "http://cedar-backup.sourceforge.net/"
 
