@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2006 Kenneth J. Pronovici.
+# Copyright (c) 2004-2006,2008 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: testutil.py 1232 2007-09-20 03:07:07Z pronovic $
+# Revision : $Id: testutil.py 879 2008-03-20 04:00:23Z pronovic $
 # Purpose  : Provides unit-testing utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -46,7 +46,7 @@ useful within the source tree.
 
 Many of these functions are in here because they are "good enough" for unit
 test work but are not robust enough to be real public functions.  Others (like
-L{removedir} do what they are supposed to, but I don't want responsibility for
+L{removedir}) do what they are supposed to, but I don't want responsibility for
 making them available to others.
 
 @sort: findResources, commandAvailable,
@@ -219,16 +219,25 @@ def extractTar(tmpdir, filepath):
 def changeFileAge(filename, subtract=None):
    """
    Changes a file age using the C{os.utime} function.
+
+   @note: Some platforms don't seem to be able to set an age precisely.  As a
+   result, whereas we might have intended to set an age of 86400 seconds, we
+   actually get an age of 86399.375 seconds.  When util.calculateFileAge()
+   looks at that the file, it calculates an age of 0.999992766204 days, which
+   then gets truncated down to zero whole days.  The tests get very confused.
+   To work around this, I always subtract off one additional second as a fudge
+   factor.  That way, the file age will be I{at least} as old as requested
+   later on.
+
    @param filename: File to operate on.
    @param subtract: Number of seconds to subtract from the current time.
    @raise ValueError: If a path cannot be encoded properly.
    """
    filename = encodePath(filename)
-   if subtract is None:
-      os.utime(filename, None)
-   else:
-      newTime = time.time() - subtract
-      os.utime(filename, (newTime, newTime))
+   newTime = time.time() - 1;
+   if subtract is not None:
+      newTime -= subtract
+   os.utime(filename, (newTime, newTime))
 
 
 ###########################
@@ -482,3 +491,28 @@ def availableLocales():
       locales.append(line.rstrip())
    return locales
 
+
+####################################
+# hexFloatLiteralAllowed() function
+####################################
+
+def hexFloatLiteralAllowed():
+   """
+   Indicates whether hex float literals are allowed by the interpreter.
+
+   As far back as 2004, some Python documentation indicated that octal and hex
+   notation applies only to integer literals.  However, prior to Python 2.5, it
+   was legal to construct a float with an argument like 0xAC.  This check
+   provides a version-based indication of whether the current interpreter
+   supports that behavior.
+
+   This check exists so that unit tests can continue to test the same thing as
+   always for pre-2.5 interpreters (i.e. making sure backwards compatibility
+   doesn't break) while still continuing to work for later interpreters.
+
+   The returned value is True for Python <= 2.5, and False otherwise.
+   """
+   if map(int, [sys.version_info[0], sys.version_info[1]]) < [2, 5]:
+      return True
+   return False
+
