@@ -9,7 +9,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2007 Kenneth J. Pronovici.
+# Copyright (c) 2007-2008 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -28,7 +28,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: splittests.py 1232 2007-09-20 03:07:07Z pronovic $
+# Revision : $Id: splittests.py 864 2008-03-18 21:26:48Z pronovic $
 # Purpose  : Tests split extension functionality.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -111,6 +111,7 @@ from CedarBackup2.filesystem import FilesystemList
 from CedarBackup2.util import UNIT_BYTES, UNIT_KBYTES, UNIT_MBYTES, UNIT_GBYTES
 from CedarBackup2.testutil import findResources, buildPath, removedir, extractTar
 from CedarBackup2.testutil import failUnlessAssignRaises, platformSupportsLinks, availableLocales
+from CedarBackup2.testutil import hexFloatLiteralAllowed
 from CedarBackup2.xmlutil import createOutputDom, serializeDom
 from CedarBackup2.extend.split import LocalConfig, SplitConfig, ByteQuantity
 from CedarBackup2.extend.split import _splitFile, _splitDailyDir
@@ -142,265 +143,6 @@ def runAllTests():
 # Test Case Classes
 #######################################################################
 
-##########################
-# TestByteQuantity class
-##########################
-
-class TestByteQuantity(unittest.TestCase):
-
-   """Tests for the ByteQuantity class."""
-
-   ##################
-   # Utility methods
-   ##################
-
-   def failUnlessAssignRaises(self, exception, object, property, value):
-      """Equivalent of L{failUnlessRaises}, but used for property assignments instead."""
-      failUnlessAssignRaises(self, exception, object, property, value)
-
-
-   ############################
-   # Test __repr__ and __str__
-   ############################
-
-   def testStringFuncs_001(self):
-      """
-      Just make sure that the string functions don't have errors (i.e. bad variable names).
-      """
-      obj = ByteQuantity()
-      obj.__repr__()
-      obj.__str__()
-
-
-   ##################################
-   # Test constructor and attributes
-   ##################################
-
-   def testConstructor_001(self):
-      """
-      Test constructor with no values filled in.
-      """
-      quantity = ByteQuantity()
-      self.failUnlessEqual(None, quantity.quantity)
-      self.failUnlessEqual(None, quantity.units)
-
-   def testConstructor_002(self):
-      """
-      Test constructor with all values filled in, with valid values.
-      """
-      quantity = ByteQuantity("6", UNIT_BYTES)
-      self.failUnlessEqual("6", quantity.quantity)
-      self.failUnlessEqual(UNIT_BYTES, quantity.units)
-
-   def testConstructor_003(self):
-      """
-      Test assignment of quantity attribute, None value.
-      """
-      quantity = ByteQuantity(quantity="1.0")
-      self.failUnlessEqual("1.0", quantity.quantity)
-      quantity.quantity = None
-      self.failUnlessEqual(None, quantity.quantity)
-
-   def testConstructor_004(self):
-      """
-      Test assignment of quantity attribute, valid values.
-      """
-      quantity = ByteQuantity()
-      self.failUnlessEqual(None, quantity.quantity)
-      quantity.quantity = "1.0"
-      self.failUnlessEqual("1.0", quantity.quantity)
-      quantity.quantity = ".1"
-      self.failUnlessEqual(".1", quantity.quantity)
-      quantity.quantity = "12"
-      self.failUnlessEqual("12", quantity.quantity)
-      quantity.quantity = "0.5"
-      self.failUnlessEqual("0.5", quantity.quantity)
-      quantity.quantity = "181281"
-      self.failUnlessEqual("181281", quantity.quantity)
-      quantity.quantity = "1E6"
-      self.failUnlessEqual("1E6", quantity.quantity)
-      quantity.quantity = "0.25E2"
-      self.failUnlessEqual("0.25E2", quantity.quantity)
-      quantity.quantity = "0xAC"
-      self.failUnlessEqual("0xAC", quantity.quantity)
-
-   def testConstructor_005(self):
-      """
-      Test assignment of quantity attribute, invalid value (empty).
-      """
-      quantity = ByteQuantity()
-      self.failUnlessEqual(None, quantity.quantity)
-      self.failUnlessAssignRaises(ValueError, quantity, "quantity", "")
-      self.failUnlessEqual(None, quantity.quantity)
-
-   def testConstructor_006(self):
-      """
-      Test assignment of quantity attribute, invalid value (not a floating point number).
-      """
-      quantity = ByteQuantity()
-      self.failUnlessEqual(None, quantity.quantity)
-      self.failUnlessAssignRaises(ValueError, quantity, "quantity", "blech")
-      self.failUnlessEqual(None, quantity.quantity)
-
-   def testConstructor_007(self):
-      """
-      Test assignment of quantity attribute, invalid value (negative number).
-      """
-      quantity = ByteQuantity()
-      self.failUnlessEqual(None, quantity.quantity)
-      self.failUnlessAssignRaises(ValueError, quantity, "quantity", "-3")
-      self.failUnlessEqual(None, quantity.quantity)
-      self.failUnlessAssignRaises(ValueError, quantity, "quantity", "-6.8")
-      self.failUnlessEqual(None, quantity.quantity)
-      self.failUnlessAssignRaises(ValueError, quantity, "quantity", "-0.2")
-      self.failUnlessEqual(None, quantity.quantity)
-      self.failUnlessAssignRaises(ValueError, quantity, "quantity", "-.1")
-      self.failUnlessEqual(None, quantity.quantity)
-
-   def testConstructor_008(self):
-      """
-      Test assignment of units attribute, None value.
-      """
-      quantity = ByteQuantity(units=UNIT_BYTES)
-      self.failUnlessEqual(UNIT_BYTES, quantity.units)
-      quantity.units = None
-      self.failUnlessEqual(None, quantity.units)
-
-   def testConstructor_009(self):
-      """
-      Test assignment of units attribute, valid values.
-      """
-      quantity = ByteQuantity()
-      self.failUnlessEqual(None, quantity.units)
-      quantity.units = UNIT_BYTES
-      self.failUnlessEqual(UNIT_BYTES, quantity.units)
-      quantity.units = UNIT_KBYTES
-      self.failUnlessEqual(UNIT_KBYTES, quantity.units)
-      quantity.units = UNIT_MBYTES
-      self.failUnlessEqual(UNIT_MBYTES, quantity.units)
-      quantity.units = UNIT_GBYTES
-      self.failUnlessEqual(UNIT_GBYTES, quantity.units)
-
-   def testConstructor_010(self):
-      """
-      Test assignment of units attribute, invalid value (empty).
-      """
-      quantity = ByteQuantity()
-      self.failUnlessEqual(None, quantity.units)
-      self.failUnlessAssignRaises(ValueError, quantity, "units", "")
-      self.failUnlessEqual(None, quantity.units)
-
-   def testConstructor_011(self):
-      """
-      Test assignment of units attribute, invalid value (not a valid unit).
-      """
-      quantity = ByteQuantity()
-      self.failUnlessEqual(None, quantity.units)
-      self.failUnlessAssignRaises(ValueError, quantity, "units", 16)
-      self.failUnlessEqual(None, quantity.units)
-      self.failUnlessAssignRaises(ValueError, quantity, "units", -2)
-      self.failUnlessEqual(None, quantity.units)
-      self.failUnlessAssignRaises(ValueError, quantity, "units", "bytes")
-      self.failUnlessEqual(None, quantity.units)
-      self.failUnlessAssignRaises(ValueError, quantity, "units", "B")
-      self.failUnlessEqual(None, quantity.units)
-      self.failUnlessAssignRaises(ValueError, quantity, "units", "KB")
-      self.failUnlessEqual(None, quantity.units)
-      self.failUnlessAssignRaises(ValueError, quantity, "units", "MB")
-      self.failUnlessEqual(None, quantity.units)
-      self.failUnlessAssignRaises(ValueError, quantity, "units", "GB")
-      self.failUnlessEqual(None, quantity.units)
-
-
-   ############################
-   # Test comparison operators
-   ############################
-
-   def testComparison_001(self):
-      """
-      Test comparison of two identical objects, all attributes None.
-      """
-      quantity1 = ByteQuantity()
-      quantity2 = ByteQuantity()
-      self.failUnlessEqual(quantity1, quantity2)
-      self.failUnless(quantity1 == quantity2)
-      self.failUnless(not quantity1 < quantity2)
-      self.failUnless(quantity1 <= quantity2)
-      self.failUnless(not quantity1 > quantity2)
-      self.failUnless(quantity1 >= quantity2)
-      self.failUnless(not quantity1 != quantity2)
-
-   def testComparison_002(self):
-      """
-      Test comparison of two identical objects, all attributes non-None.
-      """
-      quantity1 = ByteQuantity("12", UNIT_BYTES)
-      quantity2 = ByteQuantity("12", UNIT_BYTES)
-      self.failUnlessEqual(quantity1, quantity2)
-      self.failUnless(quantity1 == quantity2)
-      self.failUnless(not quantity1 < quantity2)
-      self.failUnless(quantity1 <= quantity2)
-      self.failUnless(not quantity1 > quantity2)
-      self.failUnless(quantity1 >= quantity2)
-      self.failUnless(not quantity1 != quantity2)
-
-   def testComparison_003(self):
-      """
-      Test comparison of two differing objects, quantity differs (one None).
-      """
-      quantity1 = ByteQuantity()
-      quantity2 = ByteQuantity(quantity="12")
-      self.failIfEqual(quantity1, quantity2)
-      self.failUnless(not quantity1 == quantity2)
-      self.failUnless(quantity1 < quantity2)
-      self.failUnless(quantity1 <= quantity2)
-      self.failUnless(not quantity1 > quantity2)
-      self.failUnless(not quantity1 >= quantity2)
-      self.failUnless(quantity1 != quantity2)
-
-   def testComparison_004(self):
-      """
-      Test comparison of two differing objects, quantity differs.
-      """
-      quantity1 = ByteQuantity("10", UNIT_BYTES)
-      quantity2 = ByteQuantity("12", UNIT_BYTES)
-      self.failIfEqual(quantity1, quantity2)
-      self.failUnless(not quantity1 == quantity2)
-      self.failUnless(quantity1 < quantity2)
-      self.failUnless(quantity1 <= quantity2)
-      self.failUnless(not quantity1 > quantity2)
-      self.failUnless(not quantity1 >= quantity2)
-      self.failUnless(quantity1 != quantity2)
-
-   def testComparison_005(self):
-      """
-      Test comparison of two differing objects, units differs (one None).
-      """
-      quantity1 = ByteQuantity()
-      quantity2 = ByteQuantity(units=UNIT_MBYTES)
-      self.failIfEqual(quantity1, quantity2)
-      self.failUnless(not quantity1 == quantity2)
-      self.failUnless(quantity1 < quantity2)
-      self.failUnless(quantity1 <= quantity2)
-      self.failUnless(not quantity1 > quantity2)
-      self.failUnless(not quantity1 >= quantity2)
-      self.failUnless(quantity1 != quantity2)
-
-   def testComparison_006(self):
-      """
-      Test comparison of two differing objects, units differs.
-      """
-      quantity1 = ByteQuantity("12", UNIT_BYTES)
-      quantity2 = ByteQuantity("12", UNIT_KBYTES)
-      self.failIfEqual(quantity1, quantity2)
-      self.failUnless(not quantity1 == quantity2)
-      self.failUnless(quantity1 < quantity2)
-      self.failUnless(quantity1 <= quantity2)
-      self.failUnless(not quantity1 > quantity2)
-      self.failUnless(not quantity1 >= quantity2)
-      self.failUnless(quantity1 != quantity2)
-
-
 ##########################
 # TestSplitConfig class
 ##########################
@@ -1342,14 +1084,12 @@ def suite():
    """Returns a suite containing all the test cases in this module."""
    if runAllTests():
       return unittest.TestSuite((
-                                 unittest.makeSuite(TestByteQuantity, 'test'), 
                                  unittest.makeSuite(TestSplitConfig, 'test'), 
                                  unittest.makeSuite(TestLocalConfig, 'test'), 
                                  unittest.makeSuite(TestFunctions, 'test'), 
                                ))
    else:
       return unittest.TestSuite((
-                                 unittest.makeSuite(TestByteQuantity, 'test'), 
                                  unittest.makeSuite(TestSplitConfig, 'test'), 
                                  unittest.makeSuite(TestLocalConfig, 'test'), 
                                ))
